Class: Google::Cloud::Monitoring::Dashboard::V1::Dashboard

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/monitoring/dashboard/v1/dashboard.rb

Overview

A Google Stackdriver dashboard. Dashboards define the content and layout of pages in the Stackdriver web application.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#column_layout::Google::Cloud::Monitoring::Dashboard::V1::ColumnLayout

Returns The content is divided into equally spaced columns and the widgets are arranged vertically.

Note: The following fields are mutually exclusive: column_layout, grid_layout, mosaic_layout, row_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Monitoring::Dashboard::V1::ColumnLayout)

    The content is divided into equally spaced columns and the widgets are arranged vertically.

    Note: The following fields are mutually exclusive: column_layout, grid_layout, mosaic_layout, row_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#dashboard_filters::Array<::Google::Cloud::Monitoring::Dashboard::V1::DashboardFilter>

Returns Filters to reduce the amount of data charted based on the filter criteria.

Returns:



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Required. The mutable, human-readable name.

Returns:

  • (::String)

    Required. The mutable, human-readable name.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String

Returns etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. An etag is returned in the response to GetDashboard, and users are expected to put that etag in the request to UpdateDashboard to ensure that their change will be applied to the same version of the Dashboard configuration. The field should not be passed during dashboard creation.

Returns:

  • (::String)

    etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. An etag is returned in the response to GetDashboard, and users are expected to put that etag in the request to UpdateDashboard to ensure that their change will be applied to the same version of the Dashboard configuration. The field should not be passed during dashboard creation.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#grid_layout::Google::Cloud::Monitoring::Dashboard::V1::GridLayout

Returns Content is arranged with a basic layout that re-flows a simple list of informational elements like widgets or tiles.

Note: The following fields are mutually exclusive: grid_layout, mosaic_layout, row_layout, column_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Monitoring::Dashboard::V1::GridLayout)

    Content is arranged with a basic layout that re-flows a simple list of informational elements like widgets or tiles.

    Note: The following fields are mutually exclusive: grid_layout, mosaic_layout, row_layout, column_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Labels applied to the dashboard.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels applied to the dashboard



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#mosaic_layout::Google::Cloud::Monitoring::Dashboard::V1::MosaicLayout

Returns The content is arranged as a grid of tiles, with each content widget occupying one or more grid blocks.

Note: The following fields are mutually exclusive: mosaic_layout, grid_layout, row_layout, column_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Monitoring::Dashboard::V1::MosaicLayout)

    The content is arranged as a grid of tiles, with each content widget occupying one or more grid blocks.

    Note: The following fields are mutually exclusive: mosaic_layout, grid_layout, row_layout, column_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The resource name of the dashboard.

Returns:

  • (::String)

    Identifier. The resource name of the dashboard.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#row_layout::Google::Cloud::Monitoring::Dashboard::V1::RowLayout

Returns The content is divided into equally spaced rows and the widgets are arranged horizontally.

Note: The following fields are mutually exclusive: row_layout, grid_layout, mosaic_layout, column_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Monitoring::Dashboard::V1::RowLayout)

    The content is divided into equally spaced rows and the widgets are arranged horizontally.

    Note: The following fields are mutually exclusive: row_layout, grid_layout, mosaic_layout, column_layout. If a field in that set is populated, all other fields in the set will automatically be cleared.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'proto_docs/google/monitoring/dashboard/v1/dashboard.rb', line 72

class Dashboard
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end