Class: Google::Cloud::Monitoring::Dashboard::V1::Widget
- Inherits:
-
Object
- Object
- Google::Cloud::Monitoring::Dashboard::V1::Widget
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/monitoring/dashboard/v1/widget.rb
Overview
Widget contains a single dashboard component and configuration of how to present the component in the dashboard.
Instance Attribute Summary collapse
-
#alert_chart ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::AlertChart
A chart of alert policy data.
-
#blank ⇒ ::Google::Protobuf::Empty
A blank space.
-
#collapsible_group ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::CollapsibleGroup
A widget that groups the other widgets.
-
#error_reporting_panel ⇒ ::Google::Monitoring::Dashboard::V1::ErrorReportingPanel
A widget that displays a list of error groups.
-
#id ⇒ ::String
Optional.
-
#incident_list ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::IncidentList
A widget that shows list of incidents.
-
#logs_panel ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::LogsPanel
A widget that shows a stream of logs.
-
#pie_chart ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::PieChart
A widget that displays timeseries data as a pie chart.
-
#scorecard ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::Scorecard
A scorecard summarizing time series data.
-
#section_header ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::SectionHeader
A widget that defines a section header for easier navigation of the dashboard.
-
#single_view_group ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::SingleViewGroup
A widget that groups the other widgets by using a dropdown menu.
-
#text ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::Text
A raw string or markdown displaying textual content.
-
#time_series_table ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::TimeSeriesTable
A widget that displays time series data in a tabular format.
-
#title ⇒ ::String
Optional.
-
#xy_chart ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::XyChart
A chart of time series data.
Instance Attribute Details
#alert_chart ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::AlertChart
Returns A chart of alert policy data.
Note: The following fields are mutually exclusive: alert_chart, xy_chart, scorecard, text, blank, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#blank ⇒ ::Google::Protobuf::Empty
Returns A blank space.
Note: The following fields are mutually exclusive: blank, xy_chart, scorecard, text, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#collapsible_group ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::CollapsibleGroup
Returns A widget that groups the other widgets. All widgets that are within the area spanned by the grouping widget are considered member widgets.
Note: The following fields are mutually exclusive: collapsible_group, xy_chart, scorecard, text, blank, alert_chart, time_series_table, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error_reporting_panel ⇒ ::Google::Monitoring::Dashboard::V1::ErrorReportingPanel
Returns A widget that displays a list of error groups.
Note: The following fields are mutually exclusive: error_reporting_panel, xy_chart, scorecard, text, blank, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns Optional. The widget id. Ids may be made up of alphanumerics, dashes and underscores. Widget ids are optional.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#incident_list ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::IncidentList
Returns A widget that shows list of incidents.
Note: The following fields are mutually exclusive: incident_list, xy_chart, scorecard, text, blank, alert_chart, time_series_table, collapsible_group, logs_panel, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#logs_panel ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::LogsPanel
Returns A widget that shows a stream of logs.
Note: The following fields are mutually exclusive: logs_panel, xy_chart, scorecard, text, blank, alert_chart, time_series_table, collapsible_group, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pie_chart ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::PieChart
Returns A widget that displays timeseries data as a pie chart.
Note: The following fields are mutually exclusive: pie_chart, xy_chart, scorecard, text, blank, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scorecard ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::Scorecard
Returns A scorecard summarizing time series data.
Note: The following fields are mutually exclusive: scorecard, xy_chart, text, blank, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#section_header ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::SectionHeader
Returns A widget that defines a section header for easier navigation of the dashboard.
Note: The following fields are mutually exclusive: section_header, xy_chart, scorecard, text, blank, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#single_view_group ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::SingleViewGroup
Returns A widget that groups the other widgets by using a dropdown menu.
Note: The following fields are mutually exclusive: single_view_group, xy_chart, scorecard, text, blank, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::Text
Returns A raw string or markdown displaying textual content.
Note: The following fields are mutually exclusive: text, xy_chart, scorecard, blank, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#time_series_table ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::TimeSeriesTable
Returns A widget that displays time series data in a tabular format.
Note: The following fields are mutually exclusive: time_series_table, xy_chart, scorecard, text, blank, alert_chart, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String
Returns Optional. The title of the widget.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#xy_chart ⇒ ::Google::Cloud::Monitoring::Dashboard::V1::XyChart
Returns A chart of time series data.
Note: The following fields are mutually exclusive: xy_chart, scorecard, text, blank, alert_chart, time_series_table, collapsible_group, logs_panel, incident_list, pie_chart, error_reporting_panel, section_header, single_view_group. If a field in that set is populated, all other fields in the set will automatically be cleared.
101 102 103 104 |
# File 'proto_docs/google/monitoring/dashboard/v1/widget.rb', line 101 class Widget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |